==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/algorith/typema.f <==
      SUBROUTINE TYPEMA(NOMA,NUMA,
     &                  NUTYP,MATYP)
C
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 07/10/2004   AUTEUR MABBAS M.ABBAS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C
      IMPLICIT     NONE
      CHARACTER*8  NOMA
      INTEGER      NUMA
      INTEGER      NUTYP
      CHARACTER*4  MATYP
C
C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : PROJMA
C ----------------------------------------------------------------------
C
C CETTE ROUTINE DONNE LE TYPE GEOMETRIQUE DE MAILLE
C
C IN  NOMA   : NOM DU MAILLAGE
C IN  NUMA   : NUMERO ABSOLU DE LA MAILLE
C OUT MATYP  : TYPE DE LA MAILLE (CAHINE)
C              POI1
C              SEG2
C              SEG3
C              TRI3
C              TRI6
C              QUA4
C              QUA8
C              QUA9
C OUT NUTYP  : TYPE DE LA MAILLE (REPERE DANS .TYPMAIL)
C
C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------
C
      CHARACTER*32       JEXNOM
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER      NTPOI1,NTSEG2,NTSEG3,NTTRI3,NTTRI6
      INTEGER      NTQUA4,NTQUA8,NTQUA9
      INTEGER      IATYMA,ITYP
C
      CALL JEMARQ ()
C
C
C     TYPE DE LA MAILLE MAITRE DE NUMERO ABSOLU NUMA
C     SEG2=2  SEG3=4  TRIA3=7  TRIA6=9  QUAD4=12  QUAD8=14  QUAD9=16
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','POI1')  , NTPOI1 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','SEG2')  , NTSEG2 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','SEG3')  , NTSEG3 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','TRIA3') , NTTRI3 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','TRIA6') , NTTRI6 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','QUAD4') , NTQUA4 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','QUAD8') , NTQUA8 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','QUAD9') , NTQUA9 )
C
      CALL JEVEUO (NOMA//'.TYPMAIL','L',IATYMA)
      ITYP  = IATYMA-1+NUMA
      NUTYP = ZI(ITYP)

      IF (NUTYP.EQ.NTPOI1) THEN
        MATYP = 'POI1'
      ELSE IF (NUTYP.EQ.NTSEG2) THEN
        MATYP = 'SEG2'
      ELSE IF (NUTYP.EQ.NTSEG3) THEN
        MATYP = 'SEG3'
      ELSE IF (NUTYP.EQ.NTTRI3) THEN
        MATYP = 'TRI3'
      ELSE IF (NUTYP.EQ.NTTRI6) THEN
        MATYP = 'TRI6'
      ELSE IF (NUTYP.EQ.NTQUA4) THEN
        MATYP = 'QUA4'
      ELSE IF (NUTYP.EQ.NTQUA8) THEN
        MATYP = 'QUA8'
      ELSE IF (NUTYP.EQ.NTQUA9) THEN
        MATYP = 'QUA9'
      ELSE 
        CALL UTMESS ('F','TYPEMA','TYPE DE MAILLE INCONNU')
      ENDIF

      CALL JEDEMA()
      
      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/algorith/typema.f <==
      SUBROUTINE TYPEMA(NOMA,NUMA,
     &                  NUTYP,MATYP)
C
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ALGORITH  DATE 07/02/2005   AUTEUR MABBAS M.ABBAS 
C ======================================================================
C COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
C (AT YOUR OPTION) ANY LATER VERSION.                                   
C                                                                       
C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
C                                                                       
C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
C   1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.         
C ======================================================================
C
      IMPLICIT     NONE
      CHARACTER*8  NOMA
      INTEGER      NUMA
      INTEGER      NUTYP
      CHARACTER*4  MATYP
C
C
C ----------------------------------------------------------------------
C ROUTINE APPELEE PAR : PROJMA
C ----------------------------------------------------------------------
C
C CETTE ROUTINE DONNE LE TYPE GEOMETRIQUE DE MAILLE
C
C IN  NOMA   : NOM DU MAILLAGE
C IN  NUMA   : NUMERO ABSOLU DE LA MAILLE
C OUT MATYP  : TYPE DE LA MAILLE (CAHINE)
C              POI1
C              SEG2
C              SEG3
C              TRI3
C              TRI6
C              QUA4
C              QUA8
C              QUA9
C OUT NUTYP  : TYPE DE LA MAILLE (REPERE DANS .TYPMAIL)
C
C -------------- DEBUT DECLARATIONS NORMALISEES JEVEUX -----------------
C
      CHARACTER*32       JEXNOM
      INTEGER            ZI
      COMMON  / IVARJE / ZI(1)
      REAL*8             ZR
      COMMON  / RVARJE / ZR(1)
      COMPLEX*16         ZC
      COMMON  / CVARJE / ZC(1)
      LOGICAL            ZL
      COMMON  / LVARJE / ZL(1)
      CHARACTER*8        ZK8
      CHARACTER*16                ZK16
      CHARACTER*24                          ZK24
      CHARACTER*32                                    ZK32
      CHARACTER*80                                              ZK80
      COMMON  / KVARJE / ZK8(1) , ZK16(1) , ZK24(1) , ZK32(1) , ZK80(1)
C
C ---------------- FIN DECLARATIONS NORMALISEES JEVEUX -----------------
C
      INTEGER      NTPOI1,NTSEG2,NTSEG3,NTTRI3,NTTRI6,NTTRI7
      INTEGER      NTQUA4,NTQUA8,NTQUA9
      INTEGER      IATYMA,ITYP
C
      CALL JEMARQ ()
C
C
C     TYPE DE LA MAILLE MAITRE DE NUMERO ABSOLU NUMA
C     SEG2=2  SEG3=4  TRIA3=7  TRIA6=9  QUAD4=12  QUAD8=14  QUAD9=16
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','POI1')  , NTPOI1 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','SEG2')  , NTSEG2 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','SEG3')  , NTSEG3 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','TRIA3') , NTTRI3 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','TRIA6') , NTTRI6 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','TRIA7') , NTTRI7 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','QUAD4') , NTQUA4 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','QUAD8') , NTQUA8 )
      CALL JENONU(JEXNOM('&CATA.TM.NOMTM','QUAD9') , NTQUA9 )
C
      CALL JEVEUO (NOMA//'.TYPMAIL','L',IATYMA)
      ITYP  = IATYMA-1+NUMA
      NUTYP = ZI(ITYP)

      IF (NUTYP.EQ.NTPOI1) THEN
        MATYP = 'POI1'
      ELSE IF (NUTYP.EQ.NTSEG2) THEN
        MATYP = 'SEG2'
      ELSE IF (NUTYP.EQ.NTSEG3) THEN
        MATYP = 'SEG3'
      ELSE IF (NUTYP.EQ.NTTRI3) THEN
        MATYP = 'TRI3'
      ELSE IF (NUTYP.EQ.NTTRI6) THEN
        MATYP = 'TRI6'
      ELSE IF (NUTYP.EQ.NTTRI7) THEN
        MATYP = 'TRI7'
      ELSE IF (NUTYP.EQ.NTQUA4) THEN
        MATYP = 'QUA4'
      ELSE IF (NUTYP.EQ.NTQUA8) THEN
        MATYP = 'QUA8'
      ELSE IF (NUTYP.EQ.NTQUA9) THEN
        MATYP = 'QUA9'
      ELSE 
        CALL UTMESS ('F','TYPEMA','TYPE DE MAILLE INCONNU')
      ENDIF

      CALL JEDEMA()
      
      END
